@@ -1,4 +1,5 @@
-PLS_glm_formula <- function(formula,data=NULL,nt=2,limQ2set=.0975,dataPredictY=dataX,modele="pls",family=NULL,typeVC="none",EstimXNA=FALSE,scaleX=TRUE,scaleY=NULL,pvals.expli=FALSE,alpha.pvals.expli=.05,MClassed=FALSE,tol_Xi=10^(-12),weights,subset,start=NULL,etastart,mustart,offset,method,control= list(),contrasts=NULL) {  
+PLS_glm_formula <- function(formula,data=NULL,nt=2,limQ2set=.0975,dataPredictY=dataX,modele="pls",family=NULL,typeVC="none",EstimXNA=FALSE,scaleX=TRUE,scaleY=NULL,pvals.expli=FALSE,alpha.pvals.expli=.05,MClassed=FALSE,tol_Xi=10^(-12),weights,subset,start=NULL,etastart,mustart,offset,method,control= list(),contrasts=NULL,sparse=FALSE,sparseStop=TRUE) {  
+
 
 ##################################################
 #                                                #
@@ -7,10 +8,7 @@ PLS_glm_formula <- function(formula,data=NULL,nt=2,limQ2set=.0975,dataPredictY=d
 ##################################################
 
 cat("____************************************************____\n")
-
-
-
-
+if(sparse){pvals.expli=TRUE}
 if (missing(data)) {data <- environment(formula)}
 mf <- mf2 <- match.call(expand.dots = FALSE)
 if (modele %in% c("pls-glm-family","pls-glm-Gamma","pls-glm-gaussian","pls-glm-inverse.gaussian","pls-glm-logistic","pls-glm-poisson")) {
@@ -159,6 +157,7 @@ res$residYChapeau=rep(mean(RepY),nrow(ExpliX))}
 
 res$computed_nt <- 0
 break_nt <- FALSE
+break_nt_sparse <- FALSE
 break_nt_vc <- FALSE
 
 for (kk in 1:nt) {
@@ -195,7 +194,19 @@ res$computed_nt <- kk
 ##############################################
 if (modele == "pls") {
 tempww <- t(XXwotNA)%*%YwotNA/(t(XXNA)%*%YwotNA^2)
+if (pvals.expli) {
+tempvalpvalstep <- 2 * pnorm(-abs(tempww)) 
+temppvalstep <- (tempvalpvalstep < alpha.pvals.expli)
+if(sparse&sparseStop){
+  if(sum(temppvalstep)==0L){
+    break_nt_sparse <- TRUE}
+  else 
+  {tempww[!temppvalstep] <- 0}}
+res$valpvalstep <- cbind(res$valpvalstep,tempvalpvalstep)
+res$pvalstep <- cbind(res$pvalstep,temppvalstep)
 }
+}
+
 
 ##############################################
 ######              PLS-GLM             ######
@@ -220,6 +231,11 @@ for (jj in 1:(res$nc)) {
     tempvalpvalstep[jj] <- tmww[4]
     temppvalstep[jj] <- (tmww[4] < alpha.pvals.expli)
 }
+if(sparse&sparseStop){
+  if(sum(temppvalstep)==0L){
+    break_nt_sparse <- TRUE}
+  else 
+  {tempww[!temppvalstep] <- 0}}
 XXwotNA[!XXNA] <- 0
 rm(jj)
 res$valpvalstep <- cbind(res$valpvalstep,tempvalpvalstep)
@@ -232,6 +248,7 @@ res$pvalstep <- cbind(res$pvalstep,temppvalstep)
 ##############################################
 if (modele %in% c("pls-glm-polr")) {
 YwotNA <- as.factor(YwotNA)
+if (!pvals.expli) {
 XXwotNA[!XXNA] <- NA
 library(MASS)
 tts <- res$tt
@@ -241,6 +258,31 @@ for (jj in 1:(res$nc)) {
 }
 XXwotNA[!XXNA] <- 0
 rm(jj,tts)}
+else {
+XXwotNA[!XXNA] <- NA
+library(MASS)
+tts <- res$tt
+tempvalpvalstep <- rep(0,res$nc)
+temppvalstep <- rep(0,res$nc)
+mf2$Hess <- TRUE
+for (jj in 1:(res$nc)) {
+    tmww <- -1*MASS:::summary.polr(eval(mf2, parent.frame()))$coefficients[kk,]
+    tempww[jj] <- tmww[1]
+    tempvalpvalstep[jj] <- 2 * pnorm(-abs(tmww[3])) 
+    temppvalstep[jj] <- (tempvalpvalstep[jj] < alpha.pvals.expli)
+}
+if(sparse&sparseStop){
+      if(sum(temppvalstep)==0L){
+        break_nt_sparse <- TRUE}
+      else 
+      {tempww[!temppvalstep] <- 0}}
+XXwotNA[!XXNA] <- 0
+rm(jj,tts)
+mf2$Hess <- FALSE
+res$valpvalstep <- cbind(res$valpvalstep,tempvalpvalstep)
+res$pvalstep <- cbind(res$pvalstep,temppvalstep)
+}
+}
 
 
 
@@ -250,6 +292,18 @@ rm(jj,tts)}
 # Computation of the components (model free) #
 #                                            #
 ##############################################
+if((break_nt_sparse)&(kk==1L)){
+cat(paste("No significant predictors (<",alpha.pvals.expli,") found\n",sep=""))
+cat(paste("Warning only one standard component (without sparse option) was thus extracted\n",sep=""))
+break_nt_sparse1 <- TRUE
+}
+if((break_nt_sparse)&!(kk==1L)){
+res$computed_nt <- kk-1
+if(!(break_nt_sparse1)){
+cat(paste("No more significant predictors (<",alpha.pvals.expli,") found\n",sep=""))
+cat(paste("Warning only ",res$computed_nt," components were thus extracted\n",sep=""))
+}
+break}
 
 tempwwnorm <- tempww/sqrt(drop(crossprod(tempww)))
 
@@ -265,28 +319,26 @@ if (na.miss.X & !na.miss.Y) {
 for (ii in 1:res$nr) {
 if(1/kappa(t(cbind(res$pp,temppp)[XXNA[ii,],])%*%cbind(res$pp,temppp)[XXNA[ii,],])<tol_Xi) {
 break_nt <- TRUE
-res$computed_nt <- kk-1
 cat(paste("Warning : determinant of t(cbind(res$pp,temppp)[XXNA[",ii,",],])%*%cbind(res$pp,temppp)[XXNA[",ii,",],] < 10^{-12}\n",sep=""))
 cat(paste("Warning only ",res$computed_nt," components could thus be extracted\n",sep=""))
 break
 }
 }
 rm(ii)
-if(break_nt==TRUE) {break}
+if(break_nt==TRUE) {res$computed_nt <- kk-1;break}
 }
 
 if (na.miss.X & !na.miss.Y) {
 for (ii in 1:nrow(PredictYwotNA)) {
 if(1/kappa(t(cbind(res$pp,temppp)[PredictYNA[ii,],])%*%cbind(res$pp,temppp)[PredictYNA[ii,],])<tol_Xi) {
 break_nt <- TRUE
-res$computed_nt <- kk-1
 cat(paste("Warning : determinant of t(cbind(res$pp,temppp)[PredictYNA[",ii,",],])%*%cbind(res$pp,temppp)[PredictYNA[",ii,",],] < 10^{-12}\n",sep=""))
 cat(paste("Warning only ",res$computed_nt," components could thus be extracted\n",sep=""))
 break
 }
 }
 rm(ii)
-if(break_nt==TRUE) {break}
+if(break_nt==TRUE) {res$computed_nt <- kk-1;break}
 }
 
 res$ww <- cbind(res$ww,tempww)
@@ -792,7 +844,7 @@ cat("____Component____",kk,"____\n")
 ##############################################
 
 
-if (pvals.expli) {
+if (pvals.expli&!(modele=="pls")) {
 res$Coeffsmodel_vals<-res$Coeffsmodel_vals[1:(dim(res$Coeffsmodel_vals)[1]-(nt-res$computed_nt)),]
 }
 
