@@ -23,7 +23,7 @@ PLS_glm_kfoldcv <- function(dataY,dataX,nt=2,limQ2set=.0975,modele="pls", family
         if (is.function(call$family)) {call$family <- call$family()}
         if (is.language(call$family)) {call$family <- eval(call$family)}
     }
-    print(family)
+    if (modele=="pls") {cat("\n", modele, "\n\n")} else {print(family)}
     if (as.character(call["tol_Xi"])=="NULL") {call$tol_Xi <- 10^(-12)}
     if (as.character(call["modele"])=="NULL") {call$modele <- "pls"}
     if (as.character(call["limQ2set"])=="NULL") {call$limQ2set <- .0975}
