@@ -1,4 +1,4 @@
-PLS_lm_formula <- function(formula,data=NULL,nt=2,limQ2set=.0975,dataPredictY=dataX,modele="pls",family=NULL,typeVC="none",EstimXNA=FALSE,scaleX=TRUE,scaleY=NULL,pvals.expli=FALSE,alpha.pvals.expli=.05,MClassed=FALSE,tol_Xi=10^(-12), weights,subset,contrasts=NULL) {
+PLS_lm_formula <- function(formula,data=NULL,nt=2,limQ2set=.0975,dataPredictY=dataX,modele="pls",family=NULL,typeVC="none",EstimXNA=FALSE,scaleX=TRUE,scaleY=NULL,pvals.expli=FALSE,alpha.pvals.expli=.05,MClassed=FALSE,tol_Xi=10^(-12), weights,subset,contrasts=NULL,sparse=FALSE,sparseStop=TRUE) {
 
 ##################################################
 #                                                #
@@ -7,7 +7,7 @@ PLS_lm_formula <- function(formula,data=NULL,nt=2,limQ2set=.0975,dataPredictY=da
 ##################################################
 
 cat("____************************************************____\n")
-
+if(sparse==TRUE){pvals.expli=TRUE}
 if (missing(data)) {data <- environment(formula)}
 mf <- match.call(expand.dots = FALSE)
 m <- match(c("formula", "data", "subset", "weights"), names(mf), 0L)
@@ -108,6 +108,7 @@ res$residYChapeau=rep(mean(RepY),nrow(ExpliX))}
 
 res$computed_nt <- 0
 break_nt <- FALSE
+break_nt_sparse <- FALSE
 break_nt_vc <- FALSE
 
 for (kk in 1:nt) {
@@ -147,6 +148,17 @@ res$computed_nt <- kk
 ##############################################
 if (modele == "pls") {
 tempww <- t(XXwotNA)%*%YwotNA/(t(XXNA)%*%YwotNA^2)
+if (pvals.expli) {
+tempvalpvalstep <- 2 * pnorm(-abs(tempww)) 
+temppvalstep <- (tempvalpvalstep < alpha.pvals.expli)
+if(sparse&sparseStop){
+  if(sum(temppvalstep)==0L){
+    break_nt_sparse <- TRUE}
+  else 
+  {tempww[!temppvalstep] <- 0}}
+res$valpvalstep <- cbind(res$valpvalstep,tempvalpvalstep)
+res$pvalstep <- cbind(res$pvalstep,temppvalstep)
+}
 }
 
 
@@ -155,6 +167,18 @@ tempww <- t(XXwotNA)%*%YwotNA/(t(XXNA)%*%YwotNA^2)
 # Computation of the components (model free) #
 #                                            #
 ##############################################
+if((break_nt_sparse==TRUE)&(kk==1L)){
+cat(paste("No significant predictors (<",alpha.pvals.expli,") found\n",sep=""))
+cat(paste("Warning only one standard component (without sparse option) was thus extracted\n",sep=""))
+break_nt_sparse1 <- TRUE
+}
+if((break_nt_sparse==TRUE)&!(kk==1L)){
+res$computed_nt <- kk-1
+if(!(break_nt_sparse1)){
+cat(paste("No more significant predictors (<",alpha.pvals.expli,") found\n",sep=""))
+cat(paste("Warning only ",res$computed_nt," components were thus extracted\n",sep=""))
+}
+break}
 
 tempwwnorm <- tempww/sqrt(drop(crossprod(tempww)))
 
@@ -170,28 +194,26 @@ if (na.miss.X & !na.miss.Y) {
 for (ii in 1:res$nr) {
 if(1/kappa(t(cbind(res$pp,temppp)[XXNA[ii,],])%*%cbind(res$pp,temppp)[XXNA[ii,],])<tol_Xi) {
 break_nt <- TRUE
-res$computed_nt <- kk-1
 cat(paste("Warning : determinant of t(cbind(res$pp,temppp)[XXNA[",ii,",],])%*%cbind(res$pp,temppp)[XXNA[",ii,",],] < 10^{-12}\n",sep=""))
 cat(paste("Warning only ",res$computed_nt," components could thus be extracted\n",sep=""))
 break
 }
 }
 rm(ii)
-if(break_nt==TRUE) {break}
+if(break_nt==TRUE) {res$computed_nt <- kk-1;break}
 }
 
 if (na.miss.X & !na.miss.Y) {
 for (ii in 1:nrow(PredictYwotNA)) {
 if(1/kappa(t(cbind(res$pp,temppp)[PredictYNA[ii,],])%*%cbind(res$pp,temppp)[PredictYNA[ii,],])<tol_Xi) {
 break_nt <- TRUE
-res$computed_nt <- kk-1
 cat(paste("Warning : determinant of t(cbind(res$pp,temppp)[PredictYNA[",ii,",],])%*%cbind(res$pp,temppp)[PredictYNA[",ii,",],] < 10^{-12}\n",sep=""))
 cat(paste("Warning only ",res$computed_nt," components could thus be extracted\n",sep=""))
 break
 }
 }
 rm(ii)
-if(break_nt==TRUE) {break}
+if(break_nt==TRUE) {res$computed_nt <- kk-1;break}
 }
 
 res$ww <- cbind(res$ww,tempww)
